==> foree_checkout-0.0.1.tar.gz: lib/foree_checkout.dart <==
library foree_checkout;

import 'dart:async';
import 'dart:convert';
import 'dart:io';
import 'dart:typed_data';
import 'package:flutter/material.dart';
import 'package:webview_flutter/webview_flutter.dart';

late WebViewController controller;
int loadprogress = 0;
var returneddata = null;
late String url;

JavascriptChannel callBackDataChannel(context, returner) {
  return JavascriptChannel(
      name: 'message',
      onMessageReceived: (JavascriptMessage message) {
        var callbackdata = message.message;
        callbackdata = utf8.decode(base64.decode(callbackdata));
      });
}

class Payment {
  /// used to open the checkout
  static Future initiateCheckOut({
    /// url if any to change pointing
    required bool isTesting,

    /// Data Recieved for proceeding payment
    required Map<String, dynamic> data,

    /// Context of your flutter application
    required BuildContext context,

    /// Callback used to send data to flutter application. Can be used to redirect the user too.
    required Function callBack,
  }) async {
    if (Platform.isAndroid) WebView.platform = SurfaceAndroidWebView();
    return showDialog(
        context: context,
        builder: (context) {
          if(isTesting == true){
            url = "https://portal-dev.riteidentity.com/ibad.html";
          }
          else{
            url = "https://checkout.foree.co/";
          }
          return WebView(
            initialUrl: url,
            javascriptMode: JavascriptMode.unrestricted,
            onWebViewCreated: (WebViewController webviewcontroller) async {
              controller = webviewcontroller;
            },
            onProgress: (int progress) {
              loadprogress = progress;
            },
            onPageFinished: (String url) async {
              String urlParamObj = json.encode(data);
              var postData = Uint8List.fromList(utf8.encode(urlParamObj));
              String encoded = base64Encode(postData);
              String function = "initiateCheckout('$encoded')";
              String viewone = "const meta = document.createElement('meta'); meta.setAttribute('content', 'width=device-width, initial-scale=1.0, maximum-scale=1.0, user-scalable=0'); meta.setAttribute('name', 'viewport'); document.getElementsByTagName('head')[0].appendChild(meta);";
              String viewtwo = "var meta = document.createElement('meta'); meta.setAttribute('content', 'width=device-width, initial-scale=1.0'); meta.setAttribute('name', 'viewport'); document.getElementsByTagName('head')[0].appendChild(meta); true";
              if(Platform.isAndroid){
                await controller.evaluateJavascript(viewone);
              }
              if(Platform.isIOS){
                await controller.evaluateJavascript(viewtwo);
              }
              await controller.evaluateJavascript(function);
            },
            javascriptChannels: Set.from([
              JavascriptChannel(
                  name: 'message',
                  onMessageReceived: (JavascriptMessage message) {
                    var callbackdata = message.message;
                    callbackdata = utf8.decode(base64.decode(callbackdata));
                    Navigator.pop(context);
                    callBack(callbackdata);
                  })
            ]),
          );
        });
  }
}

==> foree_checkout-0.0.5.tar.gz: lib/foree_checkout.dart <==
library foree_checkout;

import 'dart:async';
import 'dart:convert';
import 'dart:io';
import 'dart:typed_data';
import 'package:flutter/material.dart';
import 'package:webview_flutter/webview_flutter.dart';

late WebViewController controller;
int loadprogress = 0;
var returneddata = null;
late String url;

JavascriptChannel callBackDataChannel(context, returner) {
  return JavascriptChannel(
      name: 'message',
      onMessageReceived: (JavascriptMessage message) {
        var callbackdata = message.message;
        callbackdata = utf8.decode(base64.decode(callbackdata));
      });
}

class Foree {
  /// used to open the checkout
  static Future initiateCheckOut({
    /// url if any to change pointing
    required bool isTesting,

    /// Data Recieved for proceeding payment
    required Map<String, dynamic> data,

    /// Context of your flutter application
    required BuildContext context,

    /// Callback used to send data to flutter application. Can be used to redirect the user too.
    required Function callBack,
  }) async {
    if (Platform.isAndroid) WebView.platform = SurfaceAndroidWebView();
    return showDialog(
        context: context,
        builder: (context) {
          if(isTesting == true){
            url = "https://foree.co/assets/checkout-sdk/checkout-sandbox.html";
          }
          else{
            url = "https://foree.co/assets/checkout-sdk/checkout.html";
          }
          return WebView(
            initialUrl: url,
            javascriptMode: JavascriptMode.unrestricted,
            onWebViewCreated: (WebViewController webviewcontroller) async {
              controller = webviewcontroller;
            },
            onProgress: (int progress) {
              loadprogress = progress;
            },
            onPageFinished: (String url) async {
              String urlParamObj = json.encode(data);
              var postData = Uint8List.fromList(utf8.encode(urlParamObj));
              String encoded = base64Encode(postData);
              String function = "initiateCheckout('$encoded')";
              String viewone = "const meta = document.createElement('meta'); meta.setAttribute('content', 'width=device-width, initial-scale=1.0, maximum-scale=1.0, user-scalable=0'); meta.setAttribute('name', 'viewport'); document.getElementsByTagName('head')[0].appendChild(meta);";
              String viewtwo = "var meta = document.createElement('meta'); meta.setAttribute('content', 'width=device-width, initial-scale=1.0'); meta.setAttribute('name', 'viewport'); document.getElementsByTagName('head')[0].appendChild(meta); true";
              if(Platform.isAndroid){
                await controller.evaluateJavascript(viewone);
              }
              if(Platform.isIOS){
                await controller.evaluateJavascript(viewtwo);
              }
              await controller.evaluateJavascript(function);
            },
            javascriptChannels: Set.from([
              JavascriptChannel(
                  name: 'message',
                  onMessageReceived: (JavascriptMessage message) {
                    var callbackdata = message.message;
                    callbackdata = utf8.decode(base64.decode(callbackdata));
                    Navigator.pop(context);
                    callBack(callbackdata);
                  })
            ]),
          );
        });
  }
}
